AllStack class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
captureException(dynamic error, [StackTrace? stackTrace])
→ Future<bool>
-
Capture an exception
-
init({required String apiKey, String environment = 'development', String apiUrl = 'https://allstack-api.techsea.sa/api/client'})
→ Future<void>
-
Initialize AllStack
This must be called before using any AllStack functionality